<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => '安道尔比塞塔',
        ],
        'AED' => [
            0 => 'AED',
            1 => '阿联酋迪拉姆',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => '阿富汗尼 (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => '阿富汗尼',
        ],
        'ALK' => [
            0 => 'ALK',
            1 => '阿尔巴尼亚列克(1946–1965)',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => '阿尔巴尼亚列克',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => '亚美尼亚德拉姆',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => '荷属安的列斯盾',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => '安哥拉宽扎',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => '安哥拉宽扎 (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => '安哥拉新宽扎 (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => '安哥拉重新调整宽扎 (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => '阿根廷奥斯特拉尔',
        ],
        'ARL' => [
            0 => 'ARL',
            1 => '阿根廷法定比索 (1970–1983)',
        ],
        'ARM' => [
            0 => 'ARM',
            1 => '阿根廷比索 (1881–1970)',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => '阿根廷比索 (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => '阿根廷比索',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => '奥地利先令',
        ],
        'AUD' => [
            0 => 'AU$',
            1 => '澳大利亚元',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => '阿鲁巴弗罗林',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => '阿塞拜疆马纳特 (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => '阿塞拜疆马纳特',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => '波士尼亚-赫塞哥维纳第纳尔 (1992–1994)',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => '波斯尼亚-黑塞哥维那可兑换马克',
        ],
        'BAN' => [
            0 => 'BAN',
            1 => '波士尼亚-赫塞哥维纳新第纳尔 (1994–1997)',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => '巴巴多斯元',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => '孟加拉塔卡',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => '比利时法郎（可兑换）',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => '比利时法郎',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => '比利时法郎（金融）',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => '保加利亚硬列弗',
        ],
        'BGM' => [
            0 => 'BGM',
            1 => '保加利亚社会党列弗',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => '保加利亚列弗',
        ],
        'BGO' => [
            0 => 'BGO',
            1 => '保加利亚列弗 (1879–1952)',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => '巴林第纳尔',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => '布隆迪法郎',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => '百慕大元',
        ],
        'BND' => [
            0 => 'BND',
            1 => '文莱元',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => '玻利维亚诺',
        ],
        'BOL' => [
            0 => 'BOL',
            1 => '玻利维亚诺 (1863–1963)',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => '玻利维亚比索',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => '玻利维亚 Mvdol（资金）',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => '巴西新克鲁赛罗 (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => '巴西克鲁扎多 (1986–1989)',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => '巴西克鲁塞罗 (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => '巴西雷亚尔',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => '巴西新克鲁扎多 (1989–1990)',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => '巴西克鲁塞罗 (1993–1994)',
        ],
        'BRZ' => [
            0 => 'BRZ',
            1 => '巴西克鲁塞罗 (1942–1967)',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => '巴哈马元',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => '不丹努尔特鲁姆',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => '缅元',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => '博茨瓦纳普拉',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => '白俄罗斯新卢布 (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => '白俄罗斯卢布',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => '白俄罗斯卢布 (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => '伯利兹元',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => '加拿大元',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => '刚果法郎',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => '欧元 (WIR)',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => '瑞士法郎',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => '法郎 (WIR)',
        ],
        'CLE' => [
            0 => 'CLE',
            1 => '智利埃斯库多',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => '智利（资金）',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => '智利比索',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => '人民币（离岸）',
        ],
        'CNX' => [
            0 => 'CNX',
            1 => '中国人民银行元',
        ],
        'CNY' => [
            0 => '¥',
            1 => '人民币',
        ],
        'COP' => [
            0 => 'COP',
            1 => '哥伦比亚比索',
        ],
        'COU' => [
            0 => 'COU',
            1 => '哥伦比亚币',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => '哥斯达黎加科朗',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => '旧塞尔维亚第纳尔',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => '捷克硬克朗',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => '古巴可兑换比索',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => '古巴比索',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => '佛得角埃斯库多',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => '塞浦路斯镑',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => '捷克克朗',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => '东德马克',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => '德国马克',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => '吉布提法郎',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => '丹麦克朗',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => '多米尼加比索',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => '阿尔及利亚第纳尔',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => '厄瓜多尔苏克雷',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => '厄瓜多尔 (UVC)',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => '爱沙尼亚克朗',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => '埃及镑',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => '厄立特里亚纳克法',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => '西班牙比塞塔（帐户 A）',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => '西班牙比塞塔（兑换帐户）',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => '西班牙比塞塔',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => '埃塞俄比亚比尔',
        ],
        'EUR' => [
            0 => '€',
            1 => '欧元',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => '芬兰马克',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => '斐济元',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => '福克兰群岛镑',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => '法国法郎',
        ],
        'GBP' => [
            0 => '£',
            1 => '英镑',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => '格鲁吉亚库蓬拉瑞特',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => '格鲁吉亚拉里',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => '加纳塞第',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => '加纳塞地',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => '直布罗陀镑',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => '冈比亚达拉西',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => '几内亚法郎',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => '几内亚西里',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => '赤道几内亚埃奎勒',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => '希腊德拉克马',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => '危地马拉格查尔',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => '葡萄牙几内亚埃斯库多',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => '几内亚比绍比索',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => '圭亚那元',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => '港元',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => '洪都拉斯伦皮拉',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => '克罗地亚第纳尔',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => '克罗地亚库纳',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => '海地古德',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => '匈牙利福林',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => '印度尼西亚盾',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => '爱尔兰镑',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => '以色列镑',
        ],
        'ILR' => [
            0 => 'ILS',
            1 => '以色列谢克尔(1980–1985)',
        ],
        'ILS' => [
            0 => '₪',
            1 => '以色列新谢克尔',
        ],
        'INR' => [
            0 => '₹',
            1 => '印度卢比',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => '伊拉克第纳尔',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => '伊朗里亚尔',
        ],
        'ISJ' => [
            0 => 'ISJ',
            1 => '冰岛克朗(1918–1981)',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => '冰岛克朗',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => '意大利里拉',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => '牙买加元',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => '约旦第纳尔',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => '日元',
        ],
        'KES' => [
            0 => 'KES',
            1 => '肯尼亚先令',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => '吉尔吉斯斯坦索姆',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => '柬埔寨瑞尔',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => '科摩罗法郎',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => '朝鲜元',
        ],
        'KRH' => [
            0 => 'KRH',
            1 => '韩元 (1953–1962)',
        ],
        'KRO' => [
            0 => 'KRO',
            1 => '韩元 (1945–1953)',
        ],
        'KRW' => [
            0 => '￦',
            1 => '韩元',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => '科威特第纳尔',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => '开曼元',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => '哈萨克斯坦坚戈',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => '老挝基普',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => '黎巴嫩镑',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => '斯里兰卡卢比',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => '利比里亚元',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => '莱索托洛蒂',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => '立陶宛立特',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => '立陶宛塔咯呐司',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => '卢森堡可兑换法郎',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => '卢森堡法郎',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => '卢森堡金融法郎',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => '拉脱维亚拉特',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => '拉脱维亚卢布',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => '利比亚第纳尔',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => '摩洛哥迪拉姆',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => '摩洛哥法郎',
        ],
        'MCF' => [
            0 => 'MCF',
            1 => '摩纳哥法郎',
        ],
        'MDC' => [
            0 => 'MDC',
            1 => '摩尔多瓦库邦',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => '摩尔多瓦列伊',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => '马达加斯加阿里亚里',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => '马达加斯加法郎',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => '马其顿第纳尔',
        ],
        'MKN' => [
            0 => 'MKN',
            1 => '马其顿第纳尔 (1992–1993)',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => '马里法郎',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => '缅甸元',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => '蒙古图格里克',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => '澳门币',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => '毛里塔尼亚乌吉亚 (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => '毛里塔尼亚乌吉亚',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => '马耳他里拉',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => '马耳他镑',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => '毛里求斯卢比',
        ],
        'MVP' => [
            0 => 'MVP',
            1 => '马尔代夫卢比(1947–1981)',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => '马尔代夫卢菲亚',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => '马拉维克瓦查',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => '墨西哥比索',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => '墨西哥银比索 (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => '墨西哥（资金）',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => '马来西亚林吉特',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => '莫桑比克埃斯库多',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => '旧莫桑比克美提卡',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => '莫桑比克美提卡',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => '纳米比亚元',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => '尼日利亚奈拉',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => '尼加拉瓜科多巴 (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => '尼加拉瓜科多巴',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => '荷兰盾',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => '挪威克朗',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => '尼泊尔卢比',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => '新西兰元',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => '阿曼里亚尔',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => '巴拿马巴波亚',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => '秘鲁印第',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => '秘鲁索尔',
        ],
        'PES' => [
            0 => 'PES',
            1 => '秘鲁索尔 (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => '巴布亚新几内亚基那',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => '菲律宾比索',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => '巴基斯坦卢比',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => '波兰兹罗提',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => '波兰兹罗提 (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => '葡萄牙埃斯库多',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => '巴拉圭瓜拉尼',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => '卡塔尔里亚尔',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => '罗得西亚元',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => '旧罗马尼亚列伊',
        ],
        'RON' => [
            0 => 'RON',
            1 => '罗马尼亚列伊',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => '塞尔维亚第纳尔',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => '俄罗斯卢布',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => '俄国卢布 (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => '卢旺达法郎',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => '沙特里亚尔',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => '所罗门群岛元',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => '塞舌尔卢比',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => '苏丹第纳尔 (1992–2007)',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => '苏丹镑',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => '苏丹镑 (1957–1998)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => '瑞典克朗',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => '新加坡元',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => '圣赫勒拿群岛磅',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => '斯洛文尼亚托拉尔',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => '斯洛伐克克朗',
        ],
        'SLE' => [
            0 => 'SLE',
            1 => '塞拉利昂新利昂',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => '塞拉利昂利昂',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => '索马里先令',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => '苏里南元',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => '苏里南盾',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => '南苏丹镑',
        ],
        'STD' => [
            0 => 'STD',
            1 => '圣多美和普林西比多布拉 (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => '圣多美和普林西比多布拉',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => '苏联卢布',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => '萨尔瓦多科朗',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => '叙利亚镑',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => '斯威士兰里兰吉尼',
        ],
        'THB' => [
            0 => 'THB',
            1 => '泰铢',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => '塔吉克斯坦卢布',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => '塔吉克斯坦索莫尼',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => '土库曼斯坦马纳特 (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => '土库曼斯坦马纳特',
        ],
        'TND' => [
            0 => 'TND',
            1 => '突尼斯第纳尔',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => '汤加潘加',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => '帝汶埃斯库多',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => '土耳其里拉 (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => '土耳其里拉',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => '特立尼达和多巴哥元',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => '新台币',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => '坦桑尼亚先令',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => '乌克兰格里夫纳',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => '乌克兰币',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => '乌干达先令 (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => '乌干达先令',
        ],
        'USD' => [
            0 => 'US$',
            1 => '美元',
        ],
        'USN' => [
            0 => 'USN',
            1 => '美元（次日）',
        ],
        'USS' => [
            0 => 'USS',
            1 => '美元（当日）',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => '乌拉圭比索（索引单位）',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => '乌拉圭比索 (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => '乌拉圭比索',
        ],
        'UYW' => [
            0 => 'UYW',
            1 => '乌拉圭票面工资指数单位',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => '乌兹别克斯坦苏姆',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => '委内瑞拉玻利瓦尔 (1871–2008)',
        ],
        'VED' => [
            0 => 'VED',
            1 => '委内瑞拉主权币',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => '委内瑞拉玻利瓦尔 (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => '委内瑞拉玻利瓦尔',
        ],
        'VND' => [
            0 => '₫',
            1 => '越南盾',
        ],
        'VNN' => [
            0 => 'VNN',
            1 => '越南盾 (1978–1985)',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => '瓦努阿图瓦图',
        ],
        'WST' => [
            0 => 'WST',
            1 => '萨摩亚塔拉',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => '中非法郎',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => '东加勒比元',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => '欧洲货币单位',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => '法国金法郎',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => '法国法郎 (UIC)',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => '西非法郎',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => '太平洋法郎',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'RINET 基金',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => '也门第纳尔',
        ],
        'YER' => [
            0 => 'YER',
            1 => '也门里亚尔',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => '南斯拉夫硬第纳尔 (1966–1990)',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => '南斯拉夫新第纳尔 (1994–2002)',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => '南斯拉夫可兑换第纳尔 (1990–1992)',
        ],
        'YUR' => [
            0 => 'YUR',
            1 => '南斯拉夫改良第纳尔 (1992–1993)',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => '南非兰特 (金融)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => '南非兰特',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => '赞比亚克瓦查 (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => '赞比亚克瓦查',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => '新扎伊尔 (1993–1998)',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => '扎伊尔 (1971–1993)',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => '津巴布韦元 (1980–2008)',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => '津巴布韦元 (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => '津巴布韦元 (2008)',
        ],
    ],
];
